"""Settings for Inactivity."""

from app_utils.app_settings import clean_setting

INACTIVITY_TASKS_DEFAULT_PRIORITY = clean_setting(
    "INACTIVITY_TASKS_DEFAULT_PRIORITY", 6
)
"""Default priority for all tasks."""



# Generated by Django 4.2.23 on 2025-08-28 12:05

import multiselectfield.db.fields

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("inactivity", "0005_various_improvements"),
    ]

    operations = [
        migrations.AlterField(
            model_name="webhook",
            name="notification_types",
            field=multiselectfield.db.fields.MultiSelectField(
                choices=[
                    ("1", "Inactive User"),
                    ("10", "Leave of Absence - Created"),
                    ("11", "Leave of Absence - Approved"),
                ],
                help_text="only notifications of the selected types are sent to this webhook",
                max_length=7,
            ),
        ),
    ]
